@@ -1,11 +1,11 @@
 """
 Copyright 2017 Linar <linar@jether-energy.com>
-Copyright 2020 Andreas Motl <andreas.motl@panodata.org>
+Copyright 2020-2022 Andreas Motl <andreas.motl@panodata.org>
 
 License: GNU Affero General Public License, Version 3
 """
-from typing import Dict, Callable
 from dataclasses import dataclass, field
+from typing import Callable, Dict
 
 
 @dataclass
